/*
 *  Breeze  --  An application launcher with command-line style
 *  Copyright (C) 2005, 2006, 2008 Hironao Komatsu
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef USER_COMMANDS_H_INCLUDED
#define USER_COMMANDS_H_INCLUDED

extern GHashTable *user_commands;
gboolean user_commands_changed;

int insert_user_commands(gchar *keyword, gchar *command);
gconstpointer lookup_user_commands(const gchar *keyword);
void user_commands_table_foreach(GHFunc func, gpointer user_data);
int load_user_commands(void);
int save_user_commands(void);
void free_user_commands(void);

#endif
